# Grortir

Application for supporting optimization of production process.

[![Build Status](http://img.shields.io/travis/qbahn/grortir/master.svg)](https://travis-ci.org/qbahn/grortir)
[![Coverage Status](http://img.shields.io/coveralls/qbahn/grortir/master.svg)](https://coveralls.io/r/qbahn/grortir)
[![Scrutinizer Code Quality](http://img.shields.io/scrutinizer/g/qbahn/grortir.svg)](https://scrutinizer-ci.com/g/qbahn/grortir/?branch=master)
[![PyPI Version](http://img.shields.io/pypi/v/Grortir.svg)](https://pypi.python.org/pypi/Grortir)
[![PyPI Downloads](http://img.shields.io/pypi/dm/Grortir.svg)](https://pypi.python.org/pypi/Grortir)

## Getting Started

### Requirements

* Python 3.3+

### Installation

Grortir can be installed with pip:

```
$ pip install Grortir
```

or directly from the source code:

```
$ git clone https://github.com/qbahn/grortir.git
$ cd grortir
$ python setup.py install
```

## Basic Usage

After installation, the package can imported:

```
$ python
>>> import grortir
>>> grortir.__version__
```

## Documentation

Read the full documentation [here](http://qbahn.github.io/grortir).

